      FUNCTION GIMRADM(TAU,TEMP,TSKIN,KCHAN,LSFC,PSFC,EMISS)
C
C  02 mar 01  JMD  Created this GIMRADM function from subprogram,
C                  GIMRTE_NEW_GOESM, which can be found in goeswf.pgm.
C                  
C  23 jan 01  JPN  added PN variable
C  22 jan 01  JPN  version of gimrte_new.for that works with "new" transmittance
C                  model (PLOD or PFAAST) -- new FORMAT that handles the new
C                  GOES-M (GOES-12) imager with the 13.3 um channel
C  14 jan 98       switch from commom plncgo to plncgx for new trans
C  12 dec 94       correct error in sfc tau extrapolation
C
C $ SUBROUTINE GIMRTE_NEW_GOESM(TAU,TEMP,TSFC,RAD,DBDT,TBB,
C $*                            DBDTBB,KCHAN,LSFC,PSFC,DBDTS,EMISS)
C $ INTEGRATE R-T-E AND GET PLANCK-WEIGHTING PARAMETERS
C $ TAU = (R) INPUT  PROFILE OF TRANSMITTANCE
C $ TEMP = (R) INPUT  TEMPERATURE PROFILE
C $ TSKIN = (R) INPUT  SURFACE SKIN TEMPERATURE
C $ RAD = (R) OUTPUT  RADIANCE
C $ KCHAN = (I) INPUT  CHANNEL NUMBER (SOUNDER = 1-18, IMAGER = 22-25)
C $ LSFC = (I) INPUT  LEVEL SUBSCRIPT AT OR BELOW SURFACE
C $ PSFC = (R) PRESSURE AT SURFACE (CLOUD)
C $ DBDT = (R) OUTPUT  PROFILE OF DERIVATIVE OF PLANCK RADIANCE
C $                     WITH RESPECT TO ATMOSPHERIC TEMPERATURE
C $ TBB = (R) OUTPUT  BLACKBODY TEMPERATURE
C $ DBDTBB = (R) OUTPUT  DERIVATIVE OF PLANCK RADIANCE W.R.T. TBB
C $ DBDTS = (R) OUTPUT  SURFACE DBDT
C $ EMISS = (R) INPUT  SURFACE EMISSIVITY
C $$ GIMRTO = COMPUTAT,SOUNDER,GOES

      PARAMETER (NC=26,NL=40)

      DIMENSION TAU(40),TEMP(40)

      CHARACTER*12 CFI,CFF    ! McIDAS-X functions
      CHARACTER*23 PN

      DOUBLE PRECISION  DBLE  ! intrinsic function

      COMMON/ATMOS/P(NL),T(NL),W(NL),OZO(NL)
      COMMON/ATMRAD/ATRD,TAUS,REFL
c     COMMON /PLNCGO/ WNUM(NC),FK1(NC),FK2(NC),TC(2,NC)
      COMMON /PLNCGX/ WNUM(NC),FK1(NC),FK2(NC),TC(2,NC)

      DATA PN/'(GIMRADM.FOR)'/
C
C     PREPARE SURFACE CORRECTION
C
      DP = ALOG(PSFC/P(LSFC))/ALOG(P(LSFC)/P(LSFC-1))
C
C     DP IS NEGATIVE TO INTERPOLATE, POSITIVE TO EXTRAPOLATE (PSFC>NL)
C
      DTAU = TAU(LSFC-1)-TAU(LSFC)
      TAUS = TAU(LSFC)-DTAU*DP
      REFL = 0.
      F1 = FK1(KCHAN)
      F2 = FK2(KCHAN)
      Q = F2/F1
      T1 = TEMP(1)
c     B1 = PLANGO(T1,KCHAN)
c     B1 = PLANGX(T1,KCHAN)
c     goesm
      B1 = GOESPLAN(T1,KCHAN)
c     goesm
      BB = B1*B1
      TT = T1*T1
      EX = Q*EXP(F2/T1)
      TAU1 = TAU(1)
      RAD = 0.

      DO 110 I = 2,LSFC
         T2 = TEMP(I)
c        B2 = PLANGO(T2,KCHAN)
c        B2 = PLANGX(T2,KCHAN)
c        goesm
         B2 = GOESPLAN(T2,KCHAN)
c        goesm
         BB = B2*B2
         TT = T2*T2
         EX = Q*EXP(F2/T2)
         TAU2 = TAU(I)
         DTAU = TAU1-TAU2
         DR = 0.5*(B1+B2)*DTAU
         RAD = RAD+DR
         IF (TAUS .GT. 0.1.AND.EMISS .LT. 1.00) THEN
C
C           DO NOT ADD REFLECTED FOR LAST LEVEL UNLESS PSFC .GT. 1050.
C
            IF (I .EQ. LSFC.AND.PSFC .LE. 1050.) GO TO 105
            TAUB = 0.5*(TAU1+TAU2)
            TAUFAC = TAUS/TAUB
            REFL = REFL+TAUFAC*TAUFAC*DR
         ENDIF

  105    B1 = B2

  110 TAU1 = TAU2
C
C     ADD (SUBTRACT) INCREMENT OF ATMOSPHERIC RADIANCE TO REACH SURFACE
C     DP WILL BE NEGATIVE IF PSFC < 1000 MB
C     DR FALLS OUT AS THE DELTA RADIANCE OF LAYER
C
      RAD = RAD+DR*DP
C
C     ADD INCREMENT OF REFLECTED RADIANCE FOR LAYER DOWN TO SURFACE
C
      IF (TAUS .GT. 0.1.AND.EMISS .LT. 1.00) THEN
         IF (PSFC .LT. 1050.) THEN
            TAUB = 0.5*(TAU(LSFC-1)+TAUS)
C
C           CHANGE DP TO INCREMENT RATHER THAN DECREMENT
C
            DP = 1.+DP
         ELSE
            TAUB = 0.5*(TAU(LSFC)+TAUS)
         ENDIF
         TAUFAC = TAUS/TAUB
         REFL = REFL+TAUFAC*TAUFAC*DR*DP
      ENDIF

      ATRD = RAD

      RAD = RAD+(1.-EMISS)*REFL

c     BS = PLANGO(TSKIN,KCHAN)
c     BS = PLANGX(TSKIN,KCHAN)
c     goesm
      BS = GOESPLAN(TSKIN,KCHAN)
c     goesm
c     CALL SDEST(PN//'TSKIN='//CFF(DBLE(TSKIN),3),0)
c     CALL SDEST(PN//'TAUS REFL ATRD BS='//CFF(DBLE(TAUS),3)
c    *//CFF(DBLE(REFL),3)//CFF(DBLE(ATRD),3)
c    *//CFF(DBLE(BS),3)//CFF(DBLE(EMISS),2),0)

      RAD = RAD+EMISS*BS*TAUS
      RAD = AMAX1(RAD,.001)
      GIMRADM = RAD

      RETURN
      END
