	subroutine goestran(temp,wvmr,ozmr,theta,ngoes,kban,taut,*)
c
c 4/10/2001 JPN  Added code to allow McIDAS-X to find the files
c                goest[dry ozo wts wtl wco].dat anywhere within either your
c                redirection file (LWPATH.NAM) or within an MCPATH directory.
c
c * GOES/I-M dry/wet/ozo transmittance
c .... version of 22.03.01
c * updated to work with new 26-word FK1, FK2, etc. arrays (read from goestbnd.dat via GOESPFCO)

c * LarrabeeStrow/HalWoolf/PaulVanDelst regression model based on
c *	LBLRTM line-by-line transmittances.
c * Input temperatures, and water-vapor and ozone mixing ratios, must
c *	be defined at the 42 pressure levels in array 'pstd' (see block
c *   data 'reference_atmosphere' in file 'irtsub_p42.f').
c * Units: temperature, deg-K; water vapor, g/kg; ozone, ppmv.
c * Logical unit 15 is used for coefficient files.
c * Component tau's are returned through common, product in 'taut'.

c # Band (or channel) numbering scheme:
c	Sounder  1 - 18 are  1 - 18 in the context of this routine.
c	Imager   2 - 6  are 22 - 26 in the context of this routine.
c	         for GOES-I through L: 22-25
c	         for GOES-M:           22-24,26

	parameter (iuc=15,lfac=4,nk=5,nl=42,nm=nl-1,nr=23)
	parameter (nxc= 4,ncc=nxc+1,lencc=ncc*nm,lenccb=lencc*lfac)
	parameter (nxd= 8,ncd=nxd+1,lencd=ncd*nm,lencdb=lencd*lfac)
	parameter (nxo= 9,nco=nxo+1,lenco=nco*nm,lencob=lenco*lfac)
	parameter (nxl= 2,ncl=nxl+1,lencl=ncl*nm,lenclb=lencl*lfac)
	parameter (nxs=11,ncs=nxs+1,lencs=ncs*nm,lencsb=lencs*lfac)
	parameter (nxw=nxl+nxs)

	common/atmstd/pstd(nl),tstd(nl),wstd(nl),ostd(nl)

	common/taudwo/taud(nl),tauw(nl),tauo(nl)

	dimension temp(*),wvmr(*),ozmr(*),taut(*)
	dimension coefd(ncd,nm,nr),coefo(nco,nm,nr),coefl(ncl,nm,nr)
	dimension coefs(ncs,nm,nr),coefc(ncc,nm,nr)
	dimension pavg(nm),tref(nm),wref(nm),oref(nm)
	dimension tavg(nm),wamt(nm),oamt(nm),secz(nm)
	dimension tauc(nl),tlas(nl),wlas(nl),olas(nl)
	dimension xdry(nxd,nm),xozo(nxo,nm),xwet(nxw,nm),xcon(nxc,nm)

	character*3  comp(nk)
	character*12 cfile1
	character*12 cfi                     ! McIDAS-X function
	character*15 PN

	integer*4 lengcf(nk)

	integer GET_FILEPATH                 ! McIDAS-X function to return full pathname to file

	logical newang,newatm
c
c       Include the following three lines of code to allow for more
c       robust I-O in the McIDAS-X environment.
c
        include 'fileparm.inc'
        integer                   rc,ios
        character*(MAXPATHLENGTH) cfile

	data init/0/,tlas/nl*0./,wlas/nl*0./,olas/nl*0./,zlas/-999./
        data PN/'(GOESTRAN.FOR)'/
	data comp /'dry','ozo','wts','wtl','wco'/
	data cfile1 /'goestcom.dat'/
	data lengcf /lencdb,lencob,lencsb,lenclb,lenccb/

	secant(z)=1./cos(0.01745329*z)

Ctr!        CALL SDEST('ngoes ==', ngoes)
Ctr!        CALL SDEST('init ==', init) 
	if(ngoes.ne.init) then
	   koff=(ngoes-8)*nr
Ctr!           CALL SDEST('koff == ', koff)
	   do l=1,nk
	      cfile1(6:8)=comp(l)
	      lencf=lengcf(l)
c
c             Establish fully-qualified pathname.
c
              rc=GET_FILEPATH(cfile1,cfile)
              if(rc.ne.0) then
                 call edest(PN//'ERROR: cannot resolve path for '//
     *           cfile1(1:LEN_TRIM(cfile1))//'- ABORT!',0)
                 call mccodeset(100)
                 go to 200
              endif

	      open(iuc,file=cfile,recl=lencf,access='direct',
     *        status='old',iostat=ios)
              if(ios.ne.0) then
                 call edest(PN//'ERROR opening '//cfile(1:
     *           LEN_TRIM(cfile))//'= '//cfi(ios)//'- ABORT!',0)
                 call mccodeset(100)
                 go to 200
              endif

	      if(l.eq.1) then
	         do k=1,nr
		    krec=k+koff
  	            read(iuc,rec=krec,iostat=ios) 
     *              ((coefd(i,j,k),i=1,ncd),j=1,nm)
                    if(ios.ne.0) then
                       call edest(PN//'ERROR reading record #'//
     *                 cfi(krec)//
     *                 ' from '//cfile(1:LEN_TRIM(cfile))//'= '//
     *                 cfi(ios)//'- ABORT!',0)
                       call mccodeset(100)
                       go to 200
                    endif
	         enddo
	      elseif(l.eq.2) then
	         do k=1,nr
		    krec=k+koff
  	            read(iuc,rec=krec,iostat=ios) 
     *              ((coefo(i,j,k),i=1,nco),j=1,nm)
                    if(ios.ne.0) then
                       call edest(PN//'ERROR reading record #'//
     *                 cfi(krec)//
     *                 ' from '//cfile(1:LEN_TRIM(cfile))//'= '//
     *                 cfi(ios)//'- ABORT!',0)
                       call mccodeset(100)
                       go to 200
                    endif
	         enddo
	      elseif(l.eq.3) then
	         do k=1,nr
		    krec=k+koff
  	            read(iuc,rec=krec,iostat=ios) 
     *              ((coefs(i,j,k),i=1,ncs),j=1,nm)
                    if(ios.ne.0) then
                       call edest(PN//'ERROR reading record #'//
     *                 cfi(krec)//
     *                 ' from '//cfile(1:LEN_TRIM(cfile))//'= '//
     *                 cfi(ios)//'- ABORT!',0)
                       call mccodeset(100)
                       go to 200
                    endif
	         enddo
	      elseif(l.eq.4) then
	         do k=1,nr
		    krec=k+koff
  	            read(iuc,rec=krec,iostat=ios) 
     *              ((coefl(i,j,k),i=1,ncl),j=1,nm)
                    if(ios.ne.0) then
                       call edest(PN//'ERROR reading record #'//
     *                 cfi(krec)//
     *                 ' from '//cfile(1:LEN_TRIM(cfile))//'= '//
     *                 cfi(ios)//'- ABORT!',0)
                       call mccodeset(100)
                       go to 200
                    endif
	         enddo
	      elseif(l.eq.5) then
	         do k=1,nr
		    krec=k+koff
  	            read(iuc,rec=krec,iostat=ios) 
     *              ((coefc(i,j,k),i=1,ncc),j=1,nm)
                    if(ios.ne.0) then
                       call edest(PN//'ERROR reading record #'//
     *                 cfi(krec)//
     *                 ' from '//cfile(1:LEN_TRIM(cfile))//'= '//
     *                 cfi(ios)//'- ABORT!',0)
                       call mccodeset(100)
                       go to 200
                    endif
	         enddo
	      endif

	      close(iuc,iostat=ios)
              if(ios.ne.0) then
                 call edest(PN//'ERROR closing '//
     *           cfile(1:LEN_TRIM(cfile))//'= '//
     *           cfi(ios)//'- ABORT!',0)
                 call mccodeset(100)
                 go to 200
              endif

	   enddo

	   call conpir(pstd,tstd,wstd,ostd,nl,1,pavg,tref,wref,oref)
	   init=ngoes

	endif

	do j=1,nl
	   taud(j)=1.0
	   tauw(j)=1.0
	   tauc(j)=1.0
	   tauo(j)=1.0
	   taut(j)=1.0
	enddo

c ## No transmittance calculations for visible bands!

	if(kban.gt.18.and.kban.lt.22) return

c ## Following allows for IMAGER band variations

Ctr	if(ngoes.eq.12) then
	if(ngoes.le.13) then
	   if(kban.eq.25) return      ! GOES-M has no imager band 5
	else
	   if(kban.eq.26) return      ! I - L have no imager band 6
	endif

	dt=0.
	dw=0.
	do=0.
	do j=1,nl
	   dt=dt+abs(temp(j)-tlas(j))
	   tlas(j)=temp(j)
	   dw=dw+abs(wvmr(j)-wlas(j))
	   wlas(j)=wvmr(j)
	   do=do+abs(ozmr(j)-olas(j))
	   olas(j)=ozmr(j)
	enddo
	datm=dt+dw+do
	newatm=datm.ne.0.

	if(newatm) then
	   call conpir(pstd,temp,wvmr,ozmr,nl,1,pavg,tavg,wamt,oamt)
	endif

	newang=theta.ne.zlas
	if(newang) then
	   zsec=secant(theta)
	   do l=1,nm
	      secz(l)=zsec
	   enddo
	   zlas=theta
	endif

	if(newang.or.newatm) then
	   call calpir(tref,wref,oref,tavg,wamt,oamt,pavg,secz,
     +			 nm,nxd,nxw,nxo,nxc,xdry,xwet,xozo,xcon)
	endif

	k=kban
	if(kban.gt.18) k=k-3 ! k=22-25 (changes to 19-22) for GOES-I->L, k=22-24,26 (changes to 19-21,23) for GOES-M

c * dry
	call taudoc(ncd,nxd,nm,coefd(1,1,k),xdry,taud)

c * ozo
	call taudoc(nco,nxo,nm,coefo(1,1,k),xozo,tauo)

c * wet
	call tauwtr(ncs,ncl,nxs,nxl,nxw,nm,coefs(1,1,k),
     +			coefl(1,1,k),xwet,tauw)

	call taudoc(ncc,nxc,nm,coefc(1,1,k),xcon,tauc)
	do j=1,nl
	   tauw(j)=tauw(j)*tauc(j)
	enddo

c * total
	do j=1,nl
	   taut(j)=taud(j)*tauo(j)*tauw(j)
	enddo

	return

200	return1
	end
